BoardPositions, Lines and Rectangles
====================================

BoardPosition
-------------

```{eval-rst}
.. autoclass:: miniworldmaker.board_positions.board_position.BoardPosition
   :members:
```

BoardRect
-------------

```{eval-rst}
.. autoclass:: miniworldmaker.board_positions.board_rect.BoardRect
   :members:
```